@@ -47,29 +47,6 @@ void Tri( double *rcle, int *itrace, int imax )
   }
 }
 
-/* glute moche a resorber dqp */
-void TriEntier( int *rcle, int imax )
-{
-  const int isaut[]={4592,1968,861,336,112,48,21,7,3,1};
-  const int imaxsaut=sizeof(isaut)/sizeof(isaut[0]);
-  int k;
-  double vcle ;
-  for( k=0; k<imaxsaut; k++ )
-  {
-    int i;
-    for( i=isaut[k]; i<imax; i++ )
-    {
-      vcle=rcle[i];
-      int j=i;
-      while( j>=isaut[k] && rcle[j-isaut[k]]>vcle )
-      {
-        rcle[j]=rcle[j-isaut[k]];
-        j=j-isaut[k];
-      }
-      rcle[j]=vcle;
-    }
-  }
-}
 
 /*
 programmation de C_n^p, recursive et pas tres efficace,
@@ -412,21 +389,18 @@ void CopulationDet(double *rechant,
 }
 
 void PredFly( int *nbcomp, int *nbexps, int *nbinc, int *nbpreds,
-  int *subsampsize, int *mixties, int *maxtirs, int *step,
+  int *subsampsize, int *mixties, int *maxtirs,
   double *completeobs, double *incompleteobs, int *completion )
 {
   const int bloctirs=1000 ;
   int permutinc[*nbexps**nbinc], tabnbpredsfaites[*nbinc],
-    inddim, indinc, indtirs, resteapredire=1, maxstep=0 ;
+    inddim, indinc, indtirs, resteapredire=1 ;
   for (indinc=0 ; indinc<*nbinc; indinc++ )
   { tabnbpredsfaites[indinc]=0; }
   for (indinc=*nbinc**nbpreds-1 ; indinc>=0; indinc-- )
   { completion[indinc]=-1; }
   for( inddim=0; inddim<*nbexps; inddim++ )
-  {
-    Tri(&incompleteobs[inddim**nbinc],&permutinc[inddim**nbinc],*nbinc);
-    if (maxstep<step[inddim]) { maxstep=step[inddim]; } 
-  }
+  { Tri(&incompleteobs[inddim**nbinc],&permutinc[inddim**nbinc],*nbinc); }
   for ( indtirs=0 ; indtirs<*maxtirs && resteapredire==1 ; indtirs+= bloctirs )
   {
     #pragma omp parallel
@@ -434,14 +408,14 @@ void PredFly( int *nbcomp, int *nbexps, int *nbinc, int *nbpreds,
       rk_state rkfil ;
       rk_randomseed(&rkfil) ;
       int *completemp ;
-      completemp=(int *)malloc (bloctirs**nbinc*4*sizeof (int));
+      completemp=(int *)malloc (bloctirs**nbinc*4 * sizeof (int));
       int nbpredsfaites, indtirs2 ;
       nbpredsfaites=0 ;
       #pragma omp for schedule(static)
       for ( indtirs2=0 ; indtirs2< bloctirs; indtirs2++ )
       {
         nbpredsfaites+=PredFlyUnic( *nbcomp, *nbexps, *nbinc,
-          *subsampsize, *mixties, maxstep, step,
+          *subsampsize, *mixties,
           &rkfil, permutinc,
           completeobs, incompleteobs, &completemp[2*nbpredsfaites] ) ;
       }
@@ -455,7 +429,7 @@ void PredFly( int *nbcomp, int *nbexps, int *nbinc, int *nbpreds,
           {
             completion[indincourant**nbpreds+tabnbpredsfaites[indincourant]]=
               completemp[2*indpredfaite] ;
-            tabnbpredsfaites[indincourant]++;
+            tabnbpredsfaites[indincourant]++; /* ??????????????????? */
           }
         }
         resteapredire=0;
@@ -470,15 +444,14 @@ void PredFly( int *nbcomp, int *nbexps, int *nbinc, int *nbpreds,
 
 
 int PredFlyUnic( int nbcomp, int nbexps, int nbinc,
-  int subsampsize, int mixties, int maxstep, int *step,
+  int subsampsize, int mixties,
   rk_state *rkfil, int *permutincloc,
   double *completeobs, double *incompleteobs, int *completion )
 {
   int issech[subsampsize], permutss[nbexps][subsampsize],
-    voisins[nbexps][nbinc][2*maxstep],
+    voisins[nbexps][nbinc][2],
     inddim, nbpredsfaites=0 ;
   double rechtemp[nbexps][subsampsize];
-  /* tir ss-echantillon de completes, tri sur chaque dimension */
   TirSech( issech, rkfil, nbcomp, subsampsize );
   for( inddim=0; inddim<nbexps; inddim++ )
   {
@@ -490,13 +463,9 @@ int PredFlyUnic( int nbcomp, int nbexps, int nbinc,
     }
     Tri(&rechtemp[inddim][0],&permutss[inddim][0],subsampsize);
   }
-  /*
-  entrelacer ss-ech de completes et ttes incompletes, triees,
-  avec trace de l'origine de l'observation
-  */
   for( inddim=0; inddim<nbexps; inddim++ )
   {
-    int ranginc=0, rangcomp=0,indobsqcq=0,
+    int ranginc=0, rangcomp=0,indobsqcq=0, indcompdernier,
       numobsqcq[nbexps][nbinc+subsampsize], obsinc[nbexps][nbinc+subsampsize]  ;
     while( rangcomp<subsampsize && ranginc<nbinc )
     {
@@ -529,97 +498,50 @@ int PredFlyUnic( int nbcomp, int nbexps, int nbinc,
       ranginc++;
       indobsqcq++;
     }
-    /* on remplit le tableau des voisins des incompletes, dans un sens puis dans l'autre */
-    int indcompdernier[step[inddim]], indroulant, indvoisin ;
-    for (indvoisin=0; indvoisin<step[inddim]; indvoisin++)
-    { indcompdernier[indvoisin]=-1; }
-    indroulant=0;
+    indcompdernier=-1;
     for(indobsqcq=0; indobsqcq<subsampsize+nbinc; indobsqcq++)
     { 
       if (obsinc[inddim][indobsqcq]==1)
       {
-        for (indvoisin=0; indvoisin<step[inddim]; indvoisin++)
-        {
-          voisins[inddim][numobsqcq[inddim][indobsqcq]][indvoisin]=
-            indcompdernier[indvoisin] ;
-        }
+        voisins[inddim][numobsqcq[inddim][indobsqcq]][0]=indcompdernier;
       }
       else
       {
-        indcompdernier[indroulant]=numobsqcq[inddim][indobsqcq];
-        indroulant++;
-        if (indroulant>=step[inddim]) { indroulant=0; }
+        indcompdernier=numobsqcq[inddim][indobsqcq];
       }
     }
-    for (indvoisin=0; indvoisin<step[inddim]; indvoisin++)
-    { indcompdernier[indvoisin]=-1; }
-    indroulant=0;
+    indcompdernier=-1;
     for(indobsqcq=subsampsize+nbinc-1; indobsqcq>=0; indobsqcq--)
     { 
       if (obsinc[inddim][indobsqcq]==1)
       {
-        for (indvoisin=0; indvoisin<step[inddim]; indvoisin++)
-        {
-          voisins[inddim][numobsqcq[inddim][indobsqcq]][step[inddim]+indvoisin]=
-            indcompdernier[indvoisin] ;
-        }
+        voisins[inddim][numobsqcq[inddim][indobsqcq]][1]=indcompdernier;
       }
       else
       {
-        indcompdernier[indroulant]=numobsqcq[inddim][indobsqcq];
-        indroulant++;
-        if (indroulant>=step[inddim]) { indroulant=0; }
+        indcompdernier=numobsqcq[inddim][indobsqcq];
       }
     }
   }
-  /*
-  on regarde si une incomplete est voisine d'une complete sur toutes les dimensions
-  NB : l'indicage de voisins et le resultat sont des NUMEROS d'observation, pas des rangs.
-  Donc, leur egalite d'une dimension a l'autre a un sens.
-  */
   {
-    int indinc ;
+    int indinc, apres ;
     for ( indinc=0; indinc<nbinc; indinc++ )
     {
-      for( inddim=0; inddim<nbexps; inddim++ )
-      { TriEntier(&voisins[inddim][indinc][0],2*step[inddim]); }
-    }
-    for ( indinc=0; indinc<nbinc; indinc++ )
-    {
-      int obscomp, indobscomp=0, indobscomp0=0 ;
-      inddim=0;
-      obscomp=voisins[0][indinc][indobscomp0];
-      while( indobscomp0<2*step[0] )
+      for (apres=0 ; apres<=1; apres++)
       {
-        if (voisins[inddim][indinc][indobscomp]==obscomp)
+        for( inddim=1; inddim<nbexps; inddim++ )
         {
-          if (inddim==nbexps-1)
-          {
-            if (obscomp>=0)
-            {
-              completion[2*nbpredsfaites]=issech[obscomp];
-              completion[2*nbpredsfaites+1]=indinc;
-              nbpredsfaites++;
-            }
-            inddim=0;
-            obscomp=voisins[0][indinc][indobscomp0];
-            indobscomp0++;
-          } else
-          {
-            inddim++;
-            indobscomp=0;
-          }
-        } else
-        {
-          if (voisins[inddim][indinc][indobscomp]<obscomp && indobscomp < 2*step[inddim]-1)
-          { indobscomp++; } else
-          {
-            inddim=0;
-            indobscomp0++;
-            obscomp=voisins[0][indinc][indobscomp0];            
-          }
+          if (voisins[0][indinc][apres]!=voisins[inddim][indinc][0] &&
+              voisins[0][indinc][apres]!=voisins[inddim][indinc][1])
+              break ;
         }
-      }
+        if (inddim==nbexps && voisins[0][indinc][apres]>=0)
+        {
+          completion[2*nbpredsfaites]=issech[voisins[0][indinc][apres]];
+          completion[2*nbpredsfaites+1]=indinc;
+          nbpredsfaites++;
+        }
+      }      
     }
   }
   return nbpredsfaites ;
