@@ -1,14 +1,12 @@
 #include <stdlib.h>
 #include <math.h>
-#ifdef _OPENMP
+#ifdef SUPPORT_OPENMP
 #include <omp.h>
 #endif
 #include "randomkit.h"
 
 void Tri( double *cle, int *trace, int lon );
 
-void TriEntier( int *rcle, int imax );
-
 int Ajoutscopule( double *rechant, rk_state *rkfil, int *issech, int *iajoutscop,
   const int imaxssech, const int imaxechant, const int imaxdim ,
   const int imixties ) ;
@@ -23,11 +21,11 @@ double NumComb( int n, int p );
 void Combinaison( int *ssech, int numero, int n, int p );
 
 void PredFly( int *nbcomp, int *nbexps, int *nbinc, int *nbpreds,
-  int *subsampsize, int *mixties, int *maxtirs, int *step,
+  int *subsampsize, int *mixties, int *maxtirs,
   double *completeobs, double *incompleteobs, int *completion );
 
 int PredFlyUnic( int nbcomp, int nbexps, int nbinc,
-  int subsampsize, int mixties, int maxstep, int *step,
+  int subsampsize, int mixties,
   rk_state *rkfil, int *permutinc,
   double *completeobs, double *incompleteobs, int *completion );
 
